==> plasma-sdk-5.3.0.tar.xz: plasma-sdk-5.3.0/plasmate/plugins/plasmaprojectmanager/kdevplasmamanager.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=Plasma Project Manager
Name[ca]=Gestor de projectes Plasma
Name[es]=Gestor de proyectos de Plasma
Name[fi]=Plasma-projektinhallinta
Name[hu]=Plasma projektkezelő
Name[nl]=Plasma projectbeheerder
Name[pt]=Gestor de Projectos do Plasma
Name[pt_BR]=Gerenciador de Projetos do Plasma
Name[sk]=Správca projektov Plasma
Name[sl]=Upravljalnik projektov za Plasmo
Name[sv]=Plasma-projekthanterare
Name[uk]=Керування проектами Плазми
Name[x-test]=xxPlasma Project Managerxx
GenericName=Plasma Project Manager
GenericName[ca]=Gestor de projectes Plasma
GenericName[es]=Gestor de proyectos de Plasma
GenericName[fi]=Plasma-projektinhallinta
GenericName[hu]=Plasma projektkezelő
GenericName[nl]=Plasma projectbeheerder
GenericName[pt]=Gestor de Projectos do Plasma
GenericName[pt_BR]=Gerenciador de Projetos do Plasma
GenericName[sk]=Správca projektov Plasma
GenericName[sl]=Upravljalnik projektov za Plasmo
GenericName[sv]=Plasma-projekthanterare
GenericName[uk]=Керування проектами Плазми
GenericName[x-test]=xxPlasma Project Managerxx
Comment=Allow KDevPlatform to manage plasma projects
Comment[ca]=Permet al KDevPlatform gestionar els projectes de plasma
Comment[es]=Permite a KDevPlatform gestionar proyectos de Plasma
Comment[fi]=Mahdollistaa KDevPlatformin hallitsemaan Plasma-projekteja
Comment[hu]=Lehetővé teszi a Plasma projektek kezelését a KDevPlatformnak
Comment[nl]=KDevPlatform toestaan plasma-projecten te beheren
Comment[pt]=Permite ao KDevPlatform gerir projectos do Plasma
Comment[pt_BR]=Permite ao KDevPlatform gerenciar projetos do Plasma
Comment[sk]=Umožniť KDevPlatform spracovať projekty plasma
Comment[sl]=Omogoči, da KDevPlatform upravlja s projekti Plasme
Comment[sv]=Tillåter att KDevelop hanterar Plasma-projekt
Comment[uk]=Дозволяє KDevPlatform керувати проектами Плазми
Comment[x-test]=xxAllow KDevPlatform to manage plasma projectsxx
Icon=plasmagik
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevplatform/@KDEV_PLUGIN_VERSION@/kdevplasmamanager
X-KDE-PluginInfo-Name=KDevPlasmaManager
X-KDevelop-FileManager=None
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Project
X-KDevelop-Interfaces=org.kdevelop.IProjectFileManager
X-KDE-PluginInfo-Author=Giorgos Tsiapaliokas
X-KDE-PluginInfo-Category=Project Management
X-KDevelop-Mode=GUI

==> plasma-sdk-5.3.1.tar.xz: plasma-sdk-5.3.1/plasmate/plugins/plasmaprojectmanager/kdevplasmamanager.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=Plasma Project Manager
Name[ca]=Gestor de projectes Plasma
Name[de]=Plasma-Projektverwaltung
Name[en_GB]=Plasma Project Manager
Name[es]=Gestor de proyectos de Plasma
Name[fi]=Plasma-projektinhallinta
Name[hu]=Plasma projektkezelő
Name[it]=Gestore progetto Plasma
Name[nl]=Plasma projectbeheerder
Name[pl]=Zarządzanie projektami Plazmy
Name[pt]=Gestor de Projectos do Plasma
Name[pt_BR]=Gerenciador de Projetos do Plasma
Name[sk]=Správca projektov Plasma
Name[sl]=Upravljalnik projektov za Plasmo
Name[sv]=Plasma-projekthanterare
Name[uk]=Керування проектами Плазми
Name[x-test]=xxPlasma Project Managerxx
GenericName=Plasma Project Manager
GenericName[ca]=Gestor de projectes Plasma
GenericName[de]=Plasma-Projektverwaltung
GenericName[en_GB]=Plasma Project Manager
GenericName[es]=Gestor de proyectos de Plasma
GenericName[fi]=Plasma-projektinhallinta
GenericName[hu]=Plasma projektkezelő
GenericName[it]=Gestore progetto Plasma
GenericName[nl]=Plasma projectbeheerder
GenericName[pl]=Zarządzanie projektami Plazmy
GenericName[pt]=Gestor de Projectos do Plasma
GenericName[pt_BR]=Gerenciador de Projetos do Plasma
GenericName[sk]=Správca projektov Plasma
GenericName[sl]=Upravljalnik projektov za Plasmo
GenericName[sv]=Plasma-projekthanterare
GenericName[uk]=Керування проектами Плазми
GenericName[x-test]=xxPlasma Project Managerxx
Comment=Allow KDevPlatform to manage plasma projects
Comment[ca]=Permet al KDevPlatform gestionar els projectes de plasma
Comment[en_GB]=Allow KDevPlatform to manage plasma projects
Comment[es]=Permite a KDevPlatform gestionar proyectos de Plasma
Comment[fi]=Mahdollistaa KDevPlatformin hallitsemaan Plasma-projekteja
Comment[hu]=Lehetővé teszi a Plasma projektek kezelését a KDevPlatformnak
Comment[it]=Permette a KDevPlatform di gestire i progetti di plasma
Comment[nl]=KDevPlatform toestaan plasma-projecten te beheren
Comment[pl]=Zezwól KDevPlatform na zarządzanie projektami plazmy
Comment[pt]=Permite ao KDevPlatform gerir projectos do Plasma
Comment[pt_BR]=Permite ao KDevPlatform gerenciar projetos do Plasma
Comment[sk]=Umožniť KDevPlatform spracovať projekty plasma
Comment[sl]=Omogoči, da KDevPlatform upravlja s projekti Plasme
Comment[sv]=Tillåter att KDevelop hanterar Plasma-projekt
Comment[uk]=Дозволяє KDevPlatform керувати проектами Плазми
Comment[x-test]=xxAllow KDevPlatform to manage plasma projectsxx
Icon=plasmagik
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevplatform/@KDEV_PLUGIN_VERSION@/kdevplasmamanager
X-KDE-PluginInfo-Name=KDevPlasmaManager
X-KDevelop-FileManager=None
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Project
X-KDevelop-Interfaces=org.kdevelop.IProjectFileManager
X-KDE-PluginInfo-Author=Giorgos Tsiapaliokas
X-KDE-PluginInfo-Category=Project Management
X-KDevelop-Mode=GUI
